@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.1-3
+# Application Name - Health Check V0.5.1-4
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -198,6 +198,13 @@ class Ui_MainWindow(object):
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_reboot, QtCore.SIGNAL('clicked()'), self.reboot_sys)
 
+        self.pushButton_von = QtGui.QPushButton(self.tab_4)
+        self.pushButton_von.setGeometry(QtCore.QRect(10, 100, 391, 61))
+        self.pushButton_von.setObjectName("pushButton_von")
+        self.pushButton_von.setText("Test Vibrate")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
+
     
         self.tabWidget.addTab(self.tab_4, "")
 
@@ -210,7 +217,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.1-3 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.1-4 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -418,6 +425,43 @@ class Ui_MainWindow(object):
         
         self.listWidget.addItem("Accelerometer \t\t" + jaccel)
         
+        #Bluetooth
+        #print "performing inquiry..."
+        #nearby_devices = bluetooth.discover_devices(lookup_names = True)
+        #print "found %d devices" % len(nearby_devices)
+        #for name, addr in nearby_devices:
+            #print "  %s - %s" % (addr, name)
+
+    def vibrateon(self):
+        import dbus.glib
+
+        # set f to = the accellerometer co-ordinates
+        # the co-ords need to be pulled out and split for easy reading
+        # Close down the co-ord file once used (Only displaying static info, not updating yet)
+        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
+        print bb
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        b = os.popen(bb)
+        bb= 'dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_deactiv ate string:' + "\'PatternIncomingCall\'"
+        b = os.popen(bb)
+        
+        
+       
+        
         #Bluetooth
         #print "performing inquiry..."
         #nearby_devices = bluetooth.discover_devices(lookup_names = True)
@@ -498,7 +542,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-3", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-4", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
@@ -569,6 +613,7 @@ class Ui_MainWindow(object):
         #bus = dbus.SystemBus()
         #dbus_object = bus.get_object('com.nokia.phone.SIM', '/com/nokia/phone/SIM/security')
         #dbus_interface = dbus.Interface(dbus_object, 'Phone.Sim.Security')
+
         #print "imei"
         #ia = dbus_interface.get_imei()
         #ib = ia[15:]
